/* $Id: error.c,v 1.2 1995/08/10 23:19:01 sverrehu Exp $ */
/**************************************************************************
 *
 *  FILE            error.c
 *  MODULE OF       shhmsg - library for displaying messages.
 *
 *  DESCRIPTION     Function for displaying a simple error message.
 *
 *  WRITTEN BY      Sverre H. Huseby
 *
 **************************************************************************/

#include <stdio.h>
#include <stdarg.h>

#include "internal.h"
#include "shhmsg.h"

/**************************************************************************
 *                                                                        *
 *                    P U B L I C    F U N C T I O N S                    *
 *                                                                        *
 **************************************************************************/

/*-------------------------------------------------------------------------
 *
 *  NAME          msgError
 *
 *  FUNCTION      Show given message on the ERROR_STREAM.
 *
 *  SYNOPSIS      #include "shhmsg.h"
 *                void msgError(const char *format, ...);
 *
 *  INPUT         format, ...
 *                        Arguments used as with printf().
 *
 *  RETURNS       Nothing.
 *
 *  DESCRIPTION   Prints the name of this program followed by ": " and the
 *                given message on the ERROR_STREAM.
 *
 */
void msgError(const char *format, ...)
{
    va_list ap;

    fflush(stdout);
    fprintf(ERROR_STREAM, "%s: ", msgGetName());
    va_start(ap, format);
    vfprintf(ERROR_STREAM, format, ap);
    va_end(ap);
}
