/* $Id: verbose.c,v 1.3 1995/08/10 23:19:03 sverrehu Exp $ */
/**************************************************************************
 *
 *  FILE            verbose.c
 *  MODULE OF       shhmsg - library for displaying messages.
 *
 *  DESCRIPTION     Routines for displaying text according to a verbosity
 *                  level. All messages with a level less than or equal
 *                  to the current level are displayed.
 *
 *  WRITTEN BY      Sverre H. Huseby
 *
 **************************************************************************/

#include <stdio.h>
#include <stdarg.h>

#include "internal.h"
#include "shhmsg.h"

/**************************************************************************
 *                                                                        *
 *                        P U B L I C    D A T A                          *
 *                                                                        *
 **************************************************************************/

int msgVerboseLevel = 0;                       /* current verbosity level */



/**************************************************************************
 *                                                                        *
 *                    P U B L I C    F U N C T I O N S                    *
 *                                                                        *
 **************************************************************************/

/*-------------------------------------------------------------------------
 *
 *  NAME          msgSetVerbose
 *
 *  FUNCTION      Set verbosity level.
 *
 *  SYNOPSIS      #include "shhmsg.h"
 *                void msgSetVerbose(int level);
 *
 *  INPUT         level   The new verbosity level.
 *
 *  RETURNS       Nothing
 *
 *  DESCRIPTION   Used in conjunction with the msgVerbose() function.
 *                Note that changing the msgVerboseLevel-variable directly
 *                is fully legal.
 *
 */
void msgSetVerbose(int level)
{
    msgVerboseLevel = level;
}



/*-------------------------------------------------------------------------
 *
 *  NAME          msgVerbose
 *
 *  FUNCTION      Show given message if allowed by the current verb. level.
 *
 *  SYNOPSIS      #include "shhmsg.h"
 *                void msgVerbose(int level, const char *format, ...);
 *
 *  INPUT         level   The verbosity level of the message to display.
 *                format, ...
 *                        Arguments used as with printf().
 *
 *  RETURNS       Nothing
 *
 *  DESCRIPTION   The given message is displayed on the VERBOSE_STREAM if
 *                it's level is less than or equal to the current verbosity
 *                level.
 *
 */
void msgVerbose(int level, const char *format, ...)
{
    va_list ap;

    if (level > msgVerboseLevel)
        return;
    fflush(stdout);
    va_start(ap, format);
    vfprintf(VERBOSE_STREAM, format, ap);
    va_end(ap);
}
